<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Booking;
use App\Models\Patient;
use App\Models\Group;
use App\Models\Test;
use App\Models\Branch;
use App\Models\Contract;
use App\Http\Requests\Admin\BookingRequest;
use Str;
use DataTables;

class BookingsController extends Controller
{
     /**
     * assign roles
     */
    public function __construct()
    {
        $this->middleware('can:view_booking',     ['only' => ['index', 'show','ajax']]);
        $this->middleware('can:create_booking',   ['only' => ['create', 'store']]);
        $this->middleware('can:edit_booking',     ['only' => ['edit', 'update']]);
        $this->middleware('can:delete_booking',   ['only' => ['destroy']]);
        $this->middleware('can:create_group',   ['only' => ['create_tests']]);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('admin.bookings.index');
    }

     /**
    * get bookings datatable
    *
    * @access public
    * @var  @Request $request
    */
    public function ajax(Request $request)
    {
        $model=Booking::with('patient')->orderBy('id','desc');

        if($request['filter_read']!=null)
        {
            $model->where('read',$request['filter_read']);
        }

        if($request['filter_status']!=null)
        {
            $model->where('status',$request['filter_status']);
        }
        
        return DataTables::eloquent($model)

        ->editColumn('read',function($booking){
            return view('admin.bookings._read',compact('booking'));
        })
        ->editColumn('status',function($booking){
            return view('admin.bookings._status',compact('booking'));
        })
        ->addColumn('action',function($booking){
            return view('admin.bookings._action',compact('booking'));
        })
        ->toJson();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.bookings.create');
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(BookingRequest $request)
    {        

        if($request->has('patient_id'))
        {
            $patient=Patient::find($request['patient_id']);
        }
        else{
            $patient=Patient::create([
             'code'=>time(),
             'name'=>$request['name'],
             'phone'=>$request['phone'],
             'dob'=>$request['dob'],
             'address'=>$request['address'],
             'gender'=>$request['gender'],
             'email'=>$request['email'],
             'api_token'=>Str::random(32)
            ]);
        }

        $booking=Booking::create([
            'patient_id'=>$patient['id'],
            'lat'=>$request['lat'],
            'lng'=>$request['lng'],
            'zoom_level'=>$request['zoom_level'],
            'booking_date'=>$request['booking_date'],
        ]);

        if($request->has('attach'))
        {
            $attach=$request->file('attach');
            $name=time().'.'.$attach->getClientOriginalExtension();
            $attach->move('uploads/bookings',$name);
            $booking->update(['attach'=>$name]);
        }

        session()->flash('success',__('booking saved successfully'));
        
        return redirect()->route('admin.bookings.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $booking=Booking::find($id);

        $booking->update(['read'=>true]);

        return view('admin.bookings.show',compact('booking'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $booking=Booking::find($id);

        $booking->update(['read'=>true]);

        return view('admin.bookings.edit',compact('booking'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(BookingRequest $request, $id)
    {
        $booking=Booking::findOrFail($id);
        $booking->update($request->except('_token','_method','patient_type'));

        if($request->has('attach'))
        {
            $attach=$request->file('attach');
            $name=time().'.'.$attach->getClientOriginalExtension();
            $attach->move('uploads/bookings',$name);
            $booking=Booking::find($id);
            $booking->update(['attach'=>$name]);
        }

        session()->flash('success',__('booking updated successfully'));

        return redirect()->route('admin.bookings.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $booking=Booking::findOrFail($id);
        $booking->delete();

        session()->flash('success',__('booking deleted successfully'));
        
        return redirect()->route('admin.bookings.index');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
    */
    public function create_tests($booking_id)
    {
        $booking=Booking::find($booking_id);

        $booking->update([
            'read'=>true,
            'status'=>true,
        ]);

        $tests=Test::where('parent_id',0)->get();
        $branches=Branch::all();
        $contracts=Contract::all();

        return view('admin.groups.create',compact('booking','tests','branches','contracts'));
    }
}
