<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Test;
use App\Exports\TestPriceExport;
use App\Imports\TestPriceImport;
use App\Http\Requests\Admin\ExcelImportRequest;
use Excel;

class PricesController extends Controller
{
    /**
     * assign roles
     */
    public function __construct()
    {
        $this->middleware('can:view_test_prices',     ['only' => ['analyses']]);
        $this->middleware('can:update_test_prices',   ['only' => ['analyses_submit']]);
    }

    /**
     * tests price list
     *
     * @return \Illuminate\Http\Response
     */
    public function tests()
    {
        $tests=Test::where('parent_id',0)->get();

        return view('admin.prices.tests',compact('tests'));
    }

    /**
     * update tests prices
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function tests_submit(Request $request)
    {        
        if($request->has('test'))
        {
            foreach($request['test'] as $key=>$value)
            {
                Test::where('id',$key)->update([
                    'price'=>$value
                ]);
            }
        }

        session()->flash('success',__('Tests prices updated successfully'));

        return redirect()->back();
    }

    
    public function tests_prices_export()
    {
        ob_end_clean(); // this
        ob_start(); // and this
        return Excel::download(new TestPriceExport, 'tests_prices.xlsx');
    }


    /**
    * Import tests prices
    *
    * @param  int  $id
    * @return \Illuminate\Http\Response
    */
    public function tests_prices_import(ExcelImportRequest $request)
    {
        if($request->hasFile('import'))
        {
            ob_end_clean(); // this
            ob_start(); // and this

            session()->put('tests',[]);

            //import tests
            Excel::import(new TestPriceImport, $request->file('import'));        
        }

        session()->flash('success',__('Tests prices imported successfully'));

        return redirect()->back();
    }

}
