<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Test;
use App\Http\Requests\Admin\TestRequest;
use DataTables;

class TestsController extends Controller
{
     /**
     * assign roles
     */
    public function __construct()
    {
        $this->middleware('can:view_test',     ['only' => ['index', 'show','ajax']]);
        $this->middleware('can:create_test',   ['only' => ['create', 'store']]);
        $this->middleware('can:edit_test',     ['only' => ['edit', 'update']]);
        $this->middleware('can:delete_test',   ['only' => ['destroy']]);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {        
        return view('admin.tests.index');
    }
    

    /**
    * get tests datatable
    *
    * @access public
    * @var  @Request $request
    */
    public function ajax(Request $request)
    {
        $model=Test::query()->where(function($q){
            return $q->where('parent_id',0);
        });                    

        return DataTables::eloquent($model)
        ->editColumn('price',function($test){
            return formated_price($test['price']);
        })
        ->addColumn('action',function($test){
            return view('admin.tests._action',compact('test'));
        })
        ->toJson();
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.tests.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TestRequest $request)
    {
        $test=Test::create([
            'parent_id'=>0,
            'name'=>$request['name'],
            'shortcut'=>$request['shortcut'],
            'precautions'=>$request['precautions'],
            'price'=>$request['price'],
        ]);

        //create components
        if($request->has('component'))
        {
            foreach($request->component as $component)
            {
                $test_component=Test::create([
                    'parent_id'=>$test['id'],
                    'name'=>$component['name'],
                    'result_template'=>$component['result_template'],
                ]);
            }
        }
 
        session()->flash('success',__('Test created successfully'));

        return redirect()->route('admin.tests.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $test=Test::with('components')->where('id',$id)->firstOrFail();
        return view('admin.tests.edit',compact('test'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(TestRequest $request, $id)
    {
        $test=Test::findOrFail($id);

        //update analysis basic info
        $test->update([
            'parent_id'=>0,
            'name'=>$request['name'],
            'shortcut'=>$request['shortcut'],
            'precautions'=>$request['precautions'],
            'price'=>$request['price'],
        ]);

        //components
        if($request->has('component'))
        {
            foreach($request->component as $component)
            {
                if(isset($component['id']))
                {
                    $test_component=Test::where('id',$component['id'])->first();

                    $test_component->update([
                        'parent_id'=>$id,
                        'name'=>$component['name'],
                        'result_template'=>$component['result_template']
                    ]);
                }
                else{
                    $test_component=Test::create([
                        'parent_id'=>$id,
                        'name'=>$component['name'],
                        'result_template'=>$component['result_template']
                    ]);
                }
            }
        }

        session()->flash('success',__('Test updated successfully'));

        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
       $test=Test::findOrFail($id);

       //delete old components
       $components=Test::where('parent_id',$id)->get();

       foreach($components as $component)
       {
           $component->delete();
       }

        $test->delete();

        session()->flash('success',__('Test deleted successfully'));

        return redirect()->route('admin.tests.index');
    }
}
