@extends('layouts.app')

@section('title')
{{__('Edit Report')}}
@endsection

@section('breadcrumb')
<div class="content-header">
  <div class="container-fluid">
    <div class="row mb-2">
      <div class="col-sm-6">
        <h1 class="m-0 text-dark">
          <i class="fa fa-flag"></i>
          {{__('Reports')}}
        </h1>
      </div><!-- /.col -->
      <div class="col-sm-6">
        <ol class="breadcrumb float-sm-right">
          <li class="breadcrumb-item"><a href="{{route('admin.index')}}">{{__('Home')}}</a></li>
          <li class="breadcrumb-item"><a href="{{route('admin.reports.index')}}">{{__('Reports')}}</a></li>
          <li class="breadcrumb-item active">{{__('Edit Report')}}</li>
        </ol>
      </div><!-- /.col -->
    </div><!-- /.row -->
  </div><!-- /.container-fluid -->
</div>
@endsection

@section('content')
@can('view_report')
<div class="row">
  <div class="col-lg-12">

    <a href="{{route('admin.reports.show',$group['id'])}}" class="btn btn-danger float-right mb-3">
      <i class="fa fa-file-pdf"></i> {{__('Print Report')}}
    </a>

    <button type="button" class="btn btn-info float-right mb-3 mr-1" data-toggle="modal" data-target="#patient_modal">
      <i class="fas fa-user-injured"></i> {{__('Patient info')}}
    </button>

  </div>
</div>
@endcan

<!-- tests -->
<div class="card card-primary card-outline">
  <div class="card-header">
    <h3 class="card-title">{{__('Tests')}}</h3>
    <div class="card-tools">
      <button type="button" class="btn btn-tool" data-card-widget="collapse"><i class="fas fa-minus"></i></button>
      <button type="button" class="btn btn-tool" data-card-widget="remove"><i class="fas fa-times"></i></button>
    </div>
  </div>
  <!-- /.card-header -->
  <div class="card-body">
    @if(count($group['tests']))
    <div class="card card-primary card-tabs">
      <div class="card-header p-0 pt-1">
        <ul class="nav nav-tabs" id="taps">
          @foreach($group['tests'] as $test)
          <li class="nav-item">
            <a class="nav-link text-capitalize" href="#test_{{$test['id']}}" data-toggle="tab">@if($test['done']) <i class="fa fa-check text-success"></i> @endif {{$test['test']['name']}}</a>
          </li>
          @endforeach
        </ul>
      </div><!-- /.card-header -->
      <div class="card-body">
        <div class="tab-content">
          @foreach($group['tests'] as $test)
          <div class="tab-pane overflow-auto" id="test_{{$test['id']}}">
            <form action="{{route('admin.reports.update',$test['id'])}}" method="POST">
              @csrf
              @method('put')
              <table class="table table-hover table-bordered">
                <thead>
                  <th width="200px">{{__('Name')}}</th>
                  <th>{{__('Result')}}</th>
                </thead>
                <tbody>
                  @foreach($test['results'] as $result)
                    @if(isset($result['component']))
                        <tr>
                          <td>{{$result['component']['name']}}</td>
                          <td>
                            <textarea name="result[{{$result['id']}}][result]" class="form-control result" id="result_{{$result['id']}}">
                              {{$result['result']}}
                            </textarea>
                          </td>
                        </tr>
                    @endif
                  @endforeach
                </tbody>
                <tfoot>
                  <tr>
                    <td colspan="5">
                      <button class="btn btn-primary"><i class="fa fa-check"></i> {{__('Save')}}</button>
                    </td>
                  </tr>
                </tfoot>
              </table>

            </form>
          </div>
          @endforeach
          <!-- /.tab-pane -->

        </div>
        <!-- /.tab-content -->
      </div><!-- /.card-body -->
    </div>
    @else 
     <!-- check  tests selected -->
       <h6 class="text-center">
          {{__('No data available')}}
       </h6>
      <!-- End check  tests selected -->
    @endif
   
  </div>
  <!-- /.card-body -->
</div>
<!-- End tests -->

@include('admin.reports._patient_modal')

@endsection
@section('scripts')
<script src="{{url('js/admin/reports.js')}}"></script>
@endsection